@@ -246,12 +246,12 @@ def get_email():
 #
 #  send a customized email with all entries included
 #
-def send_customized_email(logmsg, emlmsg, logact = 0):
+def send_customized_email(logmsg, emlmsg, logact = LOGWRN):
 
    entries = {
       'fr' : ["From",    1, None],
       'to' : ["To",      1, None],
-      'cc' : ["Cc",      0, None],
+      'cc' : ["Cc",      0, ''],
       'sb' : ["Subject", 1, None]
    }
 
@@ -267,18 +267,20 @@ def send_customized_email(logmsg, emlmsg, logact = 0):
          vals = ms.groups()
          msg = msg.replace(vals[1], '')
          if vals[2]: entries[ekey][2] = vals[2]
-      elif logact and entries[ekey][1]:
+      elif entries[ekey][1]:
          return pglog("{}Missing Entry '{}' for sending email".format(logmsg, entry), logact|ERRLOG)
 
-   ret = send_python_email(entries['sb'][2], entries['to'][2], msg, entries['fr'][2], entries['cc'][2])
-   if ret != SUCCESS and PGLOG['EMLSEND']: ret = pgsystem(PGLOG['EMLSEND'], logact, 4, emlmsg)
+   ret = send_python_email(entries['sb'][2], entries['to'][2], msg, entries['fr'][2], entries['cc'][2], logact)
+   if ret == SUCCESS or not PGLOG['EMLSEND']: return ret
 
+   # try commandline sendmail
+   ret = pgsystem(PGLOG['EMLSEND'], logact, 4, emlmsg)
    logmsg += "Email " + entries['to'][2]
    if entries['cc'][2]: logmsg += " Cc'd " + entries['cc'][2]
    logmsg += " Subject: " + entries['sb'][2]
-   if ret:      
+   if ret:
       log_email(emlmsg)
-      if logact: pglog(logmsg, logact&(~EXITLG))
+      pglog(logmsg, logact&(~EXITLG))
    else:
       errmsg = "Error sending email: " + logmsg
       pglog(errmsg, (logact|ERRLOG)&~EXITLG)
@@ -288,14 +290,15 @@ def send_customized_email(logmsg, emlmsg, logact = 0):
 #
 #  send an email; if empty msg send email message saved in PGLOG['EMLMSG'] instead
 #
-def send_email(subject = None, receiver = None, msg = None, sender = None, logact = 0):
+def send_email(subject = None, receiver = None, msg = None, sender = None, logact = LOGWRN):
 
    return send_python_email(subject, receiver, msg, sender, None, logact)
 
 #
-#  send an email via python module smtplib; if empty msg send email message saved in PGLOG['EMLMSG'] instead
+#  send an email via python module smtplib; if empty msg send email message saved
+#  in PGLOG['EMLMSG'] instead. pass cc = '' for skipping 'Cc: '
 #
-def send_python_email(subject = None, receiver = None, msg = None, sender = None, cc = None, logact = 0):
+def send_python_email(subject = None, receiver = None, msg = None, sender = None, cc = None, logact = LOGWRN):
 
    if not msg:
       if PGLOG['EMLMSG']:
@@ -321,7 +324,7 @@ def send_python_email(subject = None, receiver = None, msg = None, sender = None
    emlmsg['From'] = sender
    emlmsg['To'] = receiver
    logmsg = "Email " + receiver
-   if not cc: cc = PGLOG['CCDADDR']
+   if cc == None: cc = PGLOG['CCDADDR']
    if cc:
       emlmsg['Cc'] = cc
       logmsg += " Cc'd " + cc
@@ -339,7 +342,7 @@ def send_python_email(subject = None, receiver = None, msg = None, sender = None
    finally:
       eml.quit()
       log_email(str(emlmsg))
-      if logact: pglog(logmsg, logact&~EXITLG)
+      pglog(logmsg, logact&~EXITLG)
       return SUCCESS
 
 #
@@ -414,7 +417,7 @@ def pglog(msg, logact = MSGLOG):
    if logact&EMLALL:
       if logact&SNDEML or not msg:
          title = (msg if msg else "Message from {}-{}".format(PGLOG['HOSTNAME'], get_command()))
-         msg = title + '\n' + msg
+         msg = title
          send_email(title.rstrip())
       elif msg:
          set_email(msg, logact)
